# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from ...core.api_error import ApiError
from ...core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ...core.http_response import AsyncHttpResponse, HttpResponse
from ...core.jsonable_encoder import jsonable_encoder
from ...core.request_options import RequestOptions
from ...core.unchecked_base_model import construct_type
from ...types.redis_import_storage import RedisImportStorage

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawRedisClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def list(
        self,
        *,
        project: int,
        ordering: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[typing.List[RedisImportStorage]]:
        """
        Get a list of all Redis import storage connections.

        Parameters
        ----------
        project : int
            Project ID

        ordering : typing.Optional[str]
            Which field to use when ordering the results.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[typing.List[RedisImportStorage]]

        """
        _response = self._client_wrapper.httpx_client.request(
            "api/storages/redis/",
            method="GET",
            params={
                "ordering": ordering,
                "project": project,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    typing.List[RedisImportStorage],
                    construct_type(
                        type_=typing.List[RedisImportStorage],  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def create(
        self,
        *,
        description: typing.Optional[str] = OMIT,
        host: typing.Optional[str] = OMIT,
        password: typing.Optional[str] = OMIT,
        path: typing.Optional[str] = OMIT,
        port: typing.Optional[str] = OMIT,
        project: typing.Optional[int] = OMIT,
        regex_filter: typing.Optional[str] = OMIT,
        title: typing.Optional[str] = OMIT,
        use_blob_urls: typing.Optional[bool] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[RedisImportStorage]:
        """
        Create a new Redis import storage connection.

        Parameters
        ----------
        description : typing.Optional[str]
            Storage description

        host : typing.Optional[str]
            Server Host IP (optional)

        password : typing.Optional[str]
            Server Password (optional)

        path : typing.Optional[str]
            Storage prefix (optional)

        port : typing.Optional[str]
            Server Port (optional)

        project : typing.Optional[int]
            Project ID

        regex_filter : typing.Optional[str]
            Cloud storage regex for filtering objects. You must specify it otherwise no objects will be imported.

        title : typing.Optional[str]
            Storage title

        use_blob_urls : typing.Optional[bool]
            Interpret objects as BLOBs and generate URLs. For example, if your bucket contains images, you can use this option to generate URLs for these images. If set to False, it will read the content of the file and load it into Label Studio.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[RedisImportStorage]

        """
        _response = self._client_wrapper.httpx_client.request(
            "api/storages/redis/",
            method="POST",
            json={
                "description": description,
                "host": host,
                "password": password,
                "path": path,
                "port": port,
                "project": project,
                "regex_filter": regex_filter,
                "title": title,
                "use_blob_urls": use_blob_urls,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    RedisImportStorage,
                    construct_type(
                        type_=RedisImportStorage,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def validate(
        self,
        *,
        description: typing.Optional[str] = OMIT,
        host: typing.Optional[str] = OMIT,
        id: typing.Optional[int] = OMIT,
        password: typing.Optional[str] = OMIT,
        path: typing.Optional[str] = OMIT,
        port: typing.Optional[str] = OMIT,
        project: typing.Optional[int] = OMIT,
        regex_filter: typing.Optional[str] = OMIT,
        title: typing.Optional[str] = OMIT,
        use_blob_urls: typing.Optional[bool] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[None]:
        """
        Validate a specific Redis import storage connection.

        Parameters
        ----------
        description : typing.Optional[str]
            Storage description

        host : typing.Optional[str]
            Server Host IP (optional)

        id : typing.Optional[int]
            Storage ID. If set, storage with specified ID will be updated

        password : typing.Optional[str]
            Server Password (optional)

        path : typing.Optional[str]
            Storage prefix (optional)

        port : typing.Optional[str]
            Server Port (optional)

        project : typing.Optional[int]
            Project ID

        regex_filter : typing.Optional[str]
            Cloud storage regex for filtering objects. You must specify it otherwise no objects will be imported.

        title : typing.Optional[str]
            Storage title

        use_blob_urls : typing.Optional[bool]
            Interpret objects as BLOBs and generate URLs. For example, if your bucket contains images, you can use this option to generate URLs for these images. If set to False, it will read the content of the file and load it into Label Studio.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[None]
        """
        _response = self._client_wrapper.httpx_client.request(
            "api/storages/redis/validate",
            method="POST",
            json={
                "description": description,
                "host": host,
                "id": id,
                "password": password,
                "path": path,
                "port": port,
                "project": project,
                "regex_filter": regex_filter,
                "title": title,
                "use_blob_urls": use_blob_urls,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return HttpResponse(response=_response, data=None)
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def get(
        self, id: int, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[RedisImportStorage]:
        """
        Get a specific Redis import storage connection.

        Parameters
        ----------
        id : int

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[RedisImportStorage]

        """
        _response = self._client_wrapper.httpx_client.request(
            f"api/storages/redis/{jsonable_encoder(id)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    RedisImportStorage,
                    construct_type(
                        type_=RedisImportStorage,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def delete(self, id: int, *, request_options: typing.Optional[RequestOptions] = None) -> HttpResponse[None]:
        """
        Delete a specific Redis import storage connection.

        Parameters
        ----------
        id : int

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[None]
        """
        _response = self._client_wrapper.httpx_client.request(
            f"api/storages/redis/{jsonable_encoder(id)}",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return HttpResponse(response=_response, data=None)
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def update(
        self,
        id: int,
        *,
        description: typing.Optional[str] = OMIT,
        host: typing.Optional[str] = OMIT,
        password: typing.Optional[str] = OMIT,
        path: typing.Optional[str] = OMIT,
        port: typing.Optional[str] = OMIT,
        project: typing.Optional[int] = OMIT,
        regex_filter: typing.Optional[str] = OMIT,
        title: typing.Optional[str] = OMIT,
        use_blob_urls: typing.Optional[bool] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[RedisImportStorage]:
        """
        Update a specific Redis import storage connection.

        Parameters
        ----------
        id : int

        description : typing.Optional[str]
            Storage description

        host : typing.Optional[str]
            Server Host IP (optional)

        password : typing.Optional[str]
            Server Password (optional)

        path : typing.Optional[str]
            Storage prefix (optional)

        port : typing.Optional[str]
            Server Port (optional)

        project : typing.Optional[int]
            Project ID

        regex_filter : typing.Optional[str]
            Cloud storage regex for filtering objects. You must specify it otherwise no objects will be imported.

        title : typing.Optional[str]
            Storage title

        use_blob_urls : typing.Optional[bool]
            Interpret objects as BLOBs and generate URLs. For example, if your bucket contains images, you can use this option to generate URLs for these images. If set to False, it will read the content of the file and load it into Label Studio.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[RedisImportStorage]

        """
        _response = self._client_wrapper.httpx_client.request(
            f"api/storages/redis/{jsonable_encoder(id)}",
            method="PATCH",
            json={
                "description": description,
                "host": host,
                "password": password,
                "path": path,
                "port": port,
                "project": project,
                "regex_filter": regex_filter,
                "title": title,
                "use_blob_urls": use_blob_urls,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    RedisImportStorage,
                    construct_type(
                        type_=RedisImportStorage,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def sync(
        self, id: int, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[RedisImportStorage]:
        """
        Sync tasks from a Redis import storage connection.

        Parameters
        ----------
        id : int
            Storage ID

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[RedisImportStorage]

        """
        _response = self._client_wrapper.httpx_client.request(
            f"api/storages/redis/{jsonable_encoder(id)}/sync",
            method="POST",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    RedisImportStorage,
                    construct_type(
                        type_=RedisImportStorage,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawRedisClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def list(
        self,
        *,
        project: int,
        ordering: typing.Optional[str] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[typing.List[RedisImportStorage]]:
        """
        Get a list of all Redis import storage connections.

        Parameters
        ----------
        project : int
            Project ID

        ordering : typing.Optional[str]
            Which field to use when ordering the results.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[typing.List[RedisImportStorage]]

        """
        _response = await self._client_wrapper.httpx_client.request(
            "api/storages/redis/",
            method="GET",
            params={
                "ordering": ordering,
                "project": project,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    typing.List[RedisImportStorage],
                    construct_type(
                        type_=typing.List[RedisImportStorage],  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def create(
        self,
        *,
        description: typing.Optional[str] = OMIT,
        host: typing.Optional[str] = OMIT,
        password: typing.Optional[str] = OMIT,
        path: typing.Optional[str] = OMIT,
        port: typing.Optional[str] = OMIT,
        project: typing.Optional[int] = OMIT,
        regex_filter: typing.Optional[str] = OMIT,
        title: typing.Optional[str] = OMIT,
        use_blob_urls: typing.Optional[bool] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[RedisImportStorage]:
        """
        Create a new Redis import storage connection.

        Parameters
        ----------
        description : typing.Optional[str]
            Storage description

        host : typing.Optional[str]
            Server Host IP (optional)

        password : typing.Optional[str]
            Server Password (optional)

        path : typing.Optional[str]
            Storage prefix (optional)

        port : typing.Optional[str]
            Server Port (optional)

        project : typing.Optional[int]
            Project ID

        regex_filter : typing.Optional[str]
            Cloud storage regex for filtering objects. You must specify it otherwise no objects will be imported.

        title : typing.Optional[str]
            Storage title

        use_blob_urls : typing.Optional[bool]
            Interpret objects as BLOBs and generate URLs. For example, if your bucket contains images, you can use this option to generate URLs for these images. If set to False, it will read the content of the file and load it into Label Studio.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[RedisImportStorage]

        """
        _response = await self._client_wrapper.httpx_client.request(
            "api/storages/redis/",
            method="POST",
            json={
                "description": description,
                "host": host,
                "password": password,
                "path": path,
                "port": port,
                "project": project,
                "regex_filter": regex_filter,
                "title": title,
                "use_blob_urls": use_blob_urls,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    RedisImportStorage,
                    construct_type(
                        type_=RedisImportStorage,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def validate(
        self,
        *,
        description: typing.Optional[str] = OMIT,
        host: typing.Optional[str] = OMIT,
        id: typing.Optional[int] = OMIT,
        password: typing.Optional[str] = OMIT,
        path: typing.Optional[str] = OMIT,
        port: typing.Optional[str] = OMIT,
        project: typing.Optional[int] = OMIT,
        regex_filter: typing.Optional[str] = OMIT,
        title: typing.Optional[str] = OMIT,
        use_blob_urls: typing.Optional[bool] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[None]:
        """
        Validate a specific Redis import storage connection.

        Parameters
        ----------
        description : typing.Optional[str]
            Storage description

        host : typing.Optional[str]
            Server Host IP (optional)

        id : typing.Optional[int]
            Storage ID. If set, storage with specified ID will be updated

        password : typing.Optional[str]
            Server Password (optional)

        path : typing.Optional[str]
            Storage prefix (optional)

        port : typing.Optional[str]
            Server Port (optional)

        project : typing.Optional[int]
            Project ID

        regex_filter : typing.Optional[str]
            Cloud storage regex for filtering objects. You must specify it otherwise no objects will be imported.

        title : typing.Optional[str]
            Storage title

        use_blob_urls : typing.Optional[bool]
            Interpret objects as BLOBs and generate URLs. For example, if your bucket contains images, you can use this option to generate URLs for these images. If set to False, it will read the content of the file and load it into Label Studio.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[None]
        """
        _response = await self._client_wrapper.httpx_client.request(
            "api/storages/redis/validate",
            method="POST",
            json={
                "description": description,
                "host": host,
                "id": id,
                "password": password,
                "path": path,
                "port": port,
                "project": project,
                "regex_filter": regex_filter,
                "title": title,
                "use_blob_urls": use_blob_urls,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return AsyncHttpResponse(response=_response, data=None)
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def get(
        self, id: int, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[RedisImportStorage]:
        """
        Get a specific Redis import storage connection.

        Parameters
        ----------
        id : int

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[RedisImportStorage]

        """
        _response = await self._client_wrapper.httpx_client.request(
            f"api/storages/redis/{jsonable_encoder(id)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    RedisImportStorage,
                    construct_type(
                        type_=RedisImportStorage,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def delete(
        self, id: int, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[None]:
        """
        Delete a specific Redis import storage connection.

        Parameters
        ----------
        id : int

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[None]
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"api/storages/redis/{jsonable_encoder(id)}",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return AsyncHttpResponse(response=_response, data=None)
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def update(
        self,
        id: int,
        *,
        description: typing.Optional[str] = OMIT,
        host: typing.Optional[str] = OMIT,
        password: typing.Optional[str] = OMIT,
        path: typing.Optional[str] = OMIT,
        port: typing.Optional[str] = OMIT,
        project: typing.Optional[int] = OMIT,
        regex_filter: typing.Optional[str] = OMIT,
        title: typing.Optional[str] = OMIT,
        use_blob_urls: typing.Optional[bool] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[RedisImportStorage]:
        """
        Update a specific Redis import storage connection.

        Parameters
        ----------
        id : int

        description : typing.Optional[str]
            Storage description

        host : typing.Optional[str]
            Server Host IP (optional)

        password : typing.Optional[str]
            Server Password (optional)

        path : typing.Optional[str]
            Storage prefix (optional)

        port : typing.Optional[str]
            Server Port (optional)

        project : typing.Optional[int]
            Project ID

        regex_filter : typing.Optional[str]
            Cloud storage regex for filtering objects. You must specify it otherwise no objects will be imported.

        title : typing.Optional[str]
            Storage title

        use_blob_urls : typing.Optional[bool]
            Interpret objects as BLOBs and generate URLs. For example, if your bucket contains images, you can use this option to generate URLs for these images. If set to False, it will read the content of the file and load it into Label Studio.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[RedisImportStorage]

        """
        _response = await self._client_wrapper.httpx_client.request(
            f"api/storages/redis/{jsonable_encoder(id)}",
            method="PATCH",
            json={
                "description": description,
                "host": host,
                "password": password,
                "path": path,
                "port": port,
                "project": project,
                "regex_filter": regex_filter,
                "title": title,
                "use_blob_urls": use_blob_urls,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    RedisImportStorage,
                    construct_type(
                        type_=RedisImportStorage,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def sync(
        self, id: int, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[RedisImportStorage]:
        """
        Sync tasks from a Redis import storage connection.

        Parameters
        ----------
        id : int
            Storage ID

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[RedisImportStorage]

        """
        _response = await self._client_wrapper.httpx_client.request(
            f"api/storages/redis/{jsonable_encoder(id)}/sync",
            method="POST",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    RedisImportStorage,
                    construct_type(
                        type_=RedisImportStorage,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)
